pub struct MemorySource { /* private fields */ }Expand description
A configuration source that holds data in memory.
Useful for testing or providing default values.
Implementations
Sourceimpl MemorySource
impl MemorySource
Sourcepub fn new(data: ConfigValue) -> Self
pub fn new(data: ConfigValue) -> Self
Create a new memory source with the given data.
Sourcepub fn with_name(data: ConfigValue, name: impl Into<String>) -> Self
pub fn with_name(data: ConfigValue, name: impl Into<String>) -> Self
Create a new memory source with a custom name.